# B

Yes.

![Caption Text Red](images/red.png "Alt Text Red")

![Caption Text Dot Dot Lime](../images/lime.png "Alt Text Dot Dot Lime")

Yes, an SVG file:

![Caption Text for SVG](diagrams/squares-and-edges.svg "Alt Text for SVG")
